@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::dzil_bundles;
 
 our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010;
 use strict;
@@ -26,7 +26,7 @@ $SPEC{handle_cmd} = {
 sub handle_cmd {
     my %args = @_;
 
-    my $res = App::lcpan::modules(%args, namespace=>'Dist::Zilla::PluginBundle');
+    my $res = App::lcpan::modules(%args, namespaces=>['Dist::Zilla::PluginBundle']);
 
     for (@{$res->[2]}) {
         if ($args{detail}) {
@@ -54,7 +54,7 @@ App::lcpan::Cmd::dzil_bundles - List Dist::Zilla bundles available on CPAN
 
 =head1 VERSION
 
-This document describes version 0.03 of App::lcpan::Cmd::dzil_bundles (from Perl distribution App-lcpan-CmdBundle-dzil), released on 2016-01-18.
+This document describes version 0.04 of App::lcpan::Cmd::dzil_bundles (from Perl distribution App-lcpan-CmdBundle-dzil), released on 2016-01-18.
 
 =head1 FUNCTIONS
 
